@@ -5,7 +5,6 @@ import base64
 from datetime import datetime
 from hashlib import sha256
 import csv
-from urllib3.exceptions import InsecureRequestWarning
 
 
 class SocketEventIsec(socketio.ClientNamespace):
@@ -281,7 +280,6 @@ class IsecConnect():
 
     def api_util(self):
         try:
-            requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
             headers = {
                 "Content-Type": "application/json"
             }
@@ -290,8 +288,8 @@ class IsecConnect():
                 "AppKey": self.api_key
             }
             body = json.dumps(body, separators=(',', ':'))
-            url = "https://uatapi.icicidirect.com/icicidirectwebapi_core/api/v1/customerdetails"
-            response = requests.get(url=url, data=body, headers=headers, verify=False)
+            url = "https://api.icicidirect.com/breezeapi/customerdetails"
+            response = requests.get(url=url, data=body, headers=headers)
             if response.json()['Success']!=None:
                 base64_session_token = response.json()['Success']['session_token']
                 result = base64.b64decode(base64_session_token.encode('ascii')).decode('ascii')
@@ -412,7 +410,7 @@ class ApificationIsec():
 
     def __init__(self, isec_instance):
         self.isec = isec_instance
-        self.hostname = 'https://uatapi.icicidirect.com/icicidirectwebapi_core/api/v1/'
+        self.hostname = 'https://api.icicidirect.com/breezeapi/'
         self.base64_session_token = base64.b64encode(
             (self.isec.user_id + ":" + self.isec.session_key).encode('ascii')).decode('ascii')
 
@@ -434,19 +432,18 @@ class ApificationIsec():
 
     def make_request(self, method, endpoint, body, headers):
         try:
-            requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
             url = self.hostname + endpoint
             if method == "GET":
-                res = requests.get(url=url, data=body, headers=headers, verify=False)
+                res = requests.get(url=url, data=body, headers=headers)
                 return res
             elif method == "POST":
-                res = requests.post(url=url, data=body, headers=headers, verify=False)
+                res = requests.post(url=url, data=body, headers=headers)
                 return res
             elif method == "PUT":
-                res = requests.put(url=url, data=body, headers=headers, verify=False)
+                res = requests.put(url=url, data=body, headers=headers)
                 return res
             elif method == "DELETE":
-                res = requests.delete(url=url, data=body, headers=headers, verify=False)
+                res = requests.delete(url=url, data=body, headers=headers)
                 return res
             else:
                 print("Invalid Request Method - Must be GET, POST, PUT or DELETE")
